==> libunibreak_5.1.orig.tar.gz: libunibreak-libunibreak_5_1/src/test_skips.h <==
static const unsigned int testSkipsWord[] = {
    0
};

static const unsigned int testSkipsGrapheme[] = {
    0
};

static const unsigned int testSkipsLine[] = {
     125,   /* Unable to tell LB30 East Asian symbols */
     127,   /* Unable to tell LB30 East Asian symbols */
     815,   /* Unable to tell LB30 East Asian symbols */
     1161,  /* Use LB25: no regex tailoring as in Example 7 */
     1163,  /* Use LB25: no regex tailoring as in Example 7 */
     1165,  /* Use LB25: no regex tailoring as in Example 7 */
     1167,  /* Use LB25: no regex tailoring as in Example 7 */
     1331,  /* Unable to tell LB30 East Asian symbols */
     2189,  /* Unable to tell LB30 East Asian symbols */
     2191,  /* Unable to tell LB30 East Asian symbols */
     2873,  /* Use LB25: no regex tailoring as in Example 7 */
     2875,  /* Use LB25: no regex tailoring as in Example 7 */
     3567,  /* Unable to tell LB30 East Asian symbols */
     3739,  /* Unable to tell LB30 East Asian symbols */
     4081,  /* Unable to tell LB30 East Asian symbols */
     4083,  /* Unable to tell LB30 East Asian symbols */
     4425,  /* Unable to tell LB30 East Asian symbols */
     4427,  /* Unable to tell LB30 East Asian symbols */
     4473,  /* Use LB25: no regex tailoring as in Example 7 */
     4475,  /* Use LB25: no regex tailoring as in Example 7 */
     4597,  /* Unable to tell LB30 East Asian symbols */
     4599,  /* Unable to tell LB30 East Asian symbols */
     4645,  /* Unable to tell LB30 East Asian symbols */
     4647,  /* Unable to tell LB30 East Asian symbols */
     4943,  /* Unable to tell LB30 East Asian symbols */
     5109,  /* Use LB25: no regex tailoring as in Example 7 */
     5111,  /* Use LB25: no regex tailoring as in Example 7 */
     5459,  /* Unable to tell LB30 East Asian symbols */
     6149,  /* Use LB25: no regex tailoring as in Example 7 */
     6151,  /* Use LB25: no regex tailoring as in Example 7 */
     6153,  /* Use LB25: no regex tailoring as in Example 7 */
     6155,  /* Use LB25: no regex tailoring as in Example 7 */
     6489,  /* Unable to tell LB30 East Asian symbols */
     6491,  /* Unable to tell LB30 East Asian symbols */
     6663,  /* Unable to tell LB30 East Asian symbols */
     6833,  /* Unable to tell LB30 East Asian symbols */
     6835,  /* Unable to tell LB30 East Asian symbols */
     7005,  /* Unable to tell LB30 East Asian symbols */
     7007,  /* Unable to tell LB30 East Asian symbols */
     7177,  /* Unable to tell LB30 East Asian symbols */
     7179,  /* Unable to tell LB30 East Asian symbols */
     7477,  /* Use LB25: no regex tailoring as in Example 7 */
     7486,  /* Use LB25: no regex tailoring as in Example 7 */
     7491,  /* Use LB25: no regex tailoring as in Example 7 */
     7576,  /* Use LB25: no regex tailoring as in Example 7 */
     7577,  /* Use LB25: no regex tailoring as in Example 7 */
     7578,  /* Use LB25: no regex tailoring as in Example 7 */
     7579,  /* Use LB25: no regex tailoring as in Example 7 */
     7580,  /* Use LB25: no regex tailoring as in Example 7 */
     7581,  /* Use LB25: no regex tailoring as in Example 7 */
     7583,  /* Use LB25: no regex tailoring as in Example 7 */
     7584,  /* Use LB25: no regex tailoring as in Example 7 */
     7585,  /* Use LB25: no regex tailoring as in Example 7 */
     7586,  /* Use LB25: no regex tailoring as in Example 7 */
     7587,  /* Use LB25: no regex tailoring as in Example 7 */
     7604,  /* Unable to tell LB30 East Asian symbols */
     7610,  /* Unable to tell LB30 East Asian symbols */
     7611,  /* Unable to tell LB30 East Asian symbols */
     7681,  /* Unknown (XX) is treated as AL in this implementation */
     0
};

==> libunibreak_6.1.orig.tar.gz: libunibreak-libunibreak_6_1/src/test_skips.h <==
static const unsigned int testSkipsWord[] = {
    0
};

static const unsigned int testSkipsGrapheme[] = {
    0
};

static const unsigned int testSkipsLine[] = {
     1161,  /* Use LB25: no regex tailoring as in Example 7 */
     1163,  /* Use LB25: no regex tailoring as in Example 7 */
     1165,  /* Use LB25: no regex tailoring as in Example 7 */
     1167,  /* Use LB25: no regex tailoring as in Example 7 */
     2873,  /* Use LB25: no regex tailoring as in Example 7 */
     2875,  /* Use LB25: no regex tailoring as in Example 7 */
     4425,  /* Use LB25: no regex tailoring as in Example 7 */
     4427,  /* Use LB25: no regex tailoring as in Example 7 */
     4473,  /* Use LB25: no regex tailoring as in Example 7 */
     4475,  /* Use LB25: no regex tailoring as in Example 7 */
     4597,  /* Use LB25: no regex tailoring as in Example 7 */
     4599,  /* Use LB25: no regex tailoring as in Example 7 */
     4645,  /* Use LB25: no regex tailoring as in Example 7 */
     4647,  /* Use LB25: no regex tailoring as in Example 7 */
     5109,  /* Use LB25: no regex tailoring as in Example 7 */
     5111,  /* Use LB25: no regex tailoring as in Example 7 */
     6149,  /* Use LB25: no regex tailoring as in Example 7 */
     6151,  /* Use LB25: no regex tailoring as in Example 7 */
     6153,  /* Use LB25: no regex tailoring as in Example 7 */
     6155,  /* Use LB25: no regex tailoring as in Example 7 */
     7477,  /* Use LB25: no regex tailoring as in Example 7 */
     7486,  /* Use LB25: no regex tailoring as in Example 7 */
     7491,  /* Use LB25: no regex tailoring as in Example 7 */
     7576,  /* Use LB25: no regex tailoring as in Example 7 */
     7577,  /* Use LB25: no regex tailoring as in Example 7 */
     7578,  /* Use LB25: no regex tailoring as in Example 7 */
     7579,  /* Use LB25: no regex tailoring as in Example 7 */
     7580,  /* Use LB25: no regex tailoring as in Example 7 */
     7581,  /* Use LB25: no regex tailoring as in Example 7 */
     7583,  /* Use LB25: no regex tailoring as in Example 7 */
     7584,  /* Use LB25: no regex tailoring as in Example 7 */
     7585,  /* Use LB25: no regex tailoring as in Example 7 */
     7586,  /* Use LB25: no regex tailoring as in Example 7 */
     7587,  /* Use LB25: no regex tailoring as in Example 7 */
     7681,  /* Unknown (XX) is treated as AL in this implementation */
     0
};
